@@ -61,6 +61,16 @@ def ensure_dir(path):
         os.makedirs(path)
 
 
+def to_cmake_version(v):
+    """
+    Helper to convert "vXrYpZ" to "X.Y.Z".
+
+    >>> to_cmake_version('v1r0p0')
+    '1.0.0'
+    """
+    return ".".join(re.findall(r"\d+", v))
+
+
 class BuildResults(object):
     '''
     Class used to analyze the build reports of projects.
@@ -281,6 +291,8 @@ class cmake_old(make):
         except (KeyError, TypeError, AttributeError):
             # no target-specific make_cmd
             pass
+        if "relaxed_install" in kwargs:
+            del kwargs["relaxed_install"]
         return make._make(self, target, proj, env=env, **kwargs)
 
     def build(self, proj, **kwargs):
@@ -366,7 +378,7 @@ class cmake_new(object):
 
     # known "kwargs" not to be propagated to subprocess
     SPECIAL_ARGS = ('jobs', 'max_load', 'args', 'make_cmd', 'cache_entries',
-                    'step')
+                    'step', 'relaxed_install')
 
     def _cache_preload_file(self, proj):
         '''
@@ -402,6 +414,14 @@ class cmake_new(object):
                 'set(CMAKE_RULE_LAUNCH_{} "lbn-wrapcmd <CMAKE_CURRENT_BINARY_DIR> <TARGET_NAME>"\n'
                 '    CACHE STRING "override")\n').format(action)
                              for action in ('COMPILE', 'LINK', 'CUSTOM'))
+            # constrain versions of projects not built in the slot
+            if proj.slot:
+                cache.writelines(
+                    'set({project}_EXACT_VERSION "{version}" CACHE STRING "")\n'
+                    .format(
+                        project=p.name, version=to_cmake_version(p.version))
+                    for p in proj.slot.projects if p.disabled)
+
         if log_writer:
             log_writer('created cache preload file:\n```{}\n{}\n```\n'.format(
                 cache_file,
@@ -545,6 +565,21 @@ class cmake_new(object):
         return result
 
     def install(self, proj, **kwargs):
+        # modify all cmake_install.cmake scripts to do not fail if an artifact
+        # is missing
+        if kwargs.get("relaxed_install"):
+            for dirpath, _dirnames, filenames in os.walk(
+                    os.path.join(proj.baseDir, 'build')):
+                if "cmake_install.cmake" in filenames:
+                    with open(os.path.join(dirpath,
+                                           "cmake_install.cmake")) as f:
+                        data = f.read()
+                    with open(
+                            os.path.join(dirpath, "cmake_install.cmake"),
+                            "w") as f:
+                        f.write(
+                            data.replace("file(INSTALL",
+                                         "file(INSTALL OPTIONAL"))
         return self._call(
             proj, [
                 'cmake', '--install',
