@@ -683,9 +683,32 @@ class Project(object):
                 open(os.path.join(proj_root,
                                   "lhcbproject.yml")))['dependencies']
 
+        def fromLHCbProjectJson():
+            '''
+            Helper to get the dependencies from a metadata file in the project,
+            called 'lhcbproject.json'.
+            The file (in JSON) must contain a `dependencies` field as a list of
+            strings
+
+            E.g.::
+
+                {
+                    "name": "MyProject",
+                    "dependencies": [
+                        "ProjectA",
+                        "ProjectB"
+                    ]
+                }
+            '''
+            import json
+            return json.load(
+                open(os.path.join(proj_root,
+                                  "lhcbproject.json")))['dependencies']
+
         # Try all the helpers until one succeeds
         deps = []
-        for helper in (fromCMake, fromCMT, fromLHCbProjectYml, fromProjInfo):
+        for helper in (fromCMake, fromCMT, fromLHCbProjectJson,
+                       fromLHCbProjectYml, fromProjInfo):
             try:
                 deps = helper()
                 break
@@ -2316,7 +2339,11 @@ def loadConfig(module=None):
     return slots
 
 
-def findSlot(name, flavour='nightly', server=None, dbname=None):
+def findSlot(name,
+             flavour='nightly',
+             server=None,
+             dbname=None,
+             raise_if_aborted=False):
     '''
     Helper to load a Slot configuration from filename or from slot name.
 
@@ -2329,7 +2356,14 @@ def findSlot(name, flavour='nightly', server=None, dbname=None):
             or Dashboard.dbName(flavour), name
         ])
         __log__.debug('retrieving %s', url)
-        return Slot.fromDict(json.load(urllib2.urlopen(url))['config'])
+        raw = json.load(urllib2.urlopen(url))
+        slot = Slot.fromDict(raw['config'])
+        if raw.get('aborted'):
+            if raise_if_aborted:
+                from LbNightlyTools.Utils import SlotAborted
+                raise SlotAborted(name, raw["aborted"])
+            slot.metadata['aborted'] = raw['aborted']
+        return slot
     elif os.path.exists(name.split('#')[0]):
         return parse(name)
     else:
