@@ -376,19 +376,29 @@ def make_mr_slots(config, model_slots):
 
 def post_gitlab_feedback(ref_slot, test_slot, flavour, mr_slots_config):
     """Post feedback on GitLab using the build ids."""
-    prefix = 'https://lhcb-nightlies.web.cern.ch/' + flavour
-    message = ('Started [reference]({prefix}/{ref_slot}/build/{ref_build}) '
-               'and [{mode} test]({prefix}/{test_slot}/build/{test_build}) '
-               'builds. Once done, check the [comparison]({prefix}/compare/'
-               '{test_slot}/{test_build}/{ref_slot}/{ref_build}) of build '
-               'and test results.'.format(
+    prefix = 'https://lhcb-nightlies.web.cern.ch/'
+    ref_id = '{flavour}/{ref_slot}/{ref_build}'.format(
+        flavour=flavour,
+        ref_slot=ref_slot.name,
+        ref_build=ref_slot.build_id,
+    )
+    test_id = '{flavour}/{test_slot}/{test_build}'.format(
+        flavour=flavour,
+        test_slot=test_slot.name,
+        test_build=test_slot.build_id,
+    )
+    message = ('Started [reference]({prefix}/{ref_id}/) '
+               'and [{mode} test]({prefix}/{test_id}/) '
+               'builds. Once done, check the [comparison]'
+               '({prefix}/compare?a={ref_id}&b={test_id})'
+               ' of build and test results.').format(
                    prefix=prefix,
+                   flavour=flavour,
+                   ref_id=ref_id,
+                   test_id=test_id,
                    mode=('integration'
                          if mr_slots_config['merge'] else 'branch'),
-                   ref_slot=ref_slot.name,
-                   ref_build=ref_slot.build_id,
-                   test_slot=test_slot.name,
-                   test_build=test_slot.build_id))
+               )
     logger.info('GitLab feedback: {!r}'.format(message))
     if os.environ.get('GITLAB_TOKEN'):
         trigger_source = mr_slots_config['trigger']
