@@ -242,6 +242,8 @@ class Script(BaseScript):
                     list(
                         chain.from_iterable(
                             descendants(deps, p) for p in needed)))
+                # - test projects that changed or depend on those that changed
+                need_testing = set(needed)
                 # - and all projects that are needed to build those we need
                 needed.update(
                     list(
@@ -249,13 +251,17 @@ class Script(BaseScript):
                             ancestors(deps, p) for p in needed)))
                 # - disable everything else
                 #   (making sure we do not enable something already disabled)
-                for p in slot.projects:
-                    idx = proj_idx[p.name]
-                    if (not cfg['projects'][idx]['disabled']
-                            and p.name not in needed):
-                        __log__.debug('disabling %s', p.name)
-                        cfg['projects'][idx]['disabled'] = True
-                        p.disabled = True
+                for p in cfg['projects']:
+                    if not p['disabled']:
+                        n = p["name"]
+                        getattr(slot,
+                                n).disabled = p['disabled'] = n not in needed
+                        getattr(
+                            slot,
+                            n).no_test = p['no_test'] = n not in need_testing
+
+                __log__.debug("projects to build: %s", needed)
+                __log__.debug("projects to test: %s", need_testing)
 
         # write the checkout log of projects to dedicated files
         for project in slot.activeProjects:
