@@ -195,6 +195,9 @@ class Script(PlainScript):
 
                 last_slot_info = d.db.get(
                     '%s.%d' % (slot.name, slot_build_ids[slot.name]), {})
+                if last_slot_info.get("aborted"):
+                    self.log.debug('  previous build was aborted')
+                    return True
 
                 # check previous build age
                 age = (to_date(self.options.date) - to_date(
