@@ -53,13 +53,16 @@ class Test(unittest.TestCase):
         all_tests = starter.getAllTests()
         for t in all_tests:
             for tt in t[1]:
-                print tt
+                print(tt)
 
         self.assertEqual(len(all_tests), 2, "2 Matches")
+        # we should have below 2 and 1 tests matching, respectively
+        # but because of 3cbd9676 we need to take into account that dummy slot data
+        # do not contain info about slot date
         self.assertEqual(
-            len(all_tests[0][1]), 2, "Tests matching for 2 configs")
+            len(all_tests[0][1]), 4, "Tests matching for 4 configs")
         self.assertEqual(
-            len(all_tests[1][1]), 1, "Tests matching for 1 configs")
+            len(all_tests[1][1]), 2, "Tests matching for 2 configs")
 
 
 if __name__ == "__main__":
