@@ -65,6 +65,21 @@ def cmpLCGVersion(x, y):
     return cmp(sanitize(x), sanitize(y))
 
 
+def convertToLHCbClassicVersion(version):
+    ''' Convert a version of the type X.Y.X to vXrYpZ.
+    Leaves the other strings unaffected
+    '''
+
+    # Case when we specify the version as point separated numbers
+    if re.match(r"^\d[\d.]*$", version):
+        # this is a X.Y CMake style version, so we map it to vXr*
+        # - get the first 4 element max (we support vXrYpZgA)
+        parts = version.split(".")[:4]
+        return "".join(a + b for a, b in zip("vrpg", parts))
+
+    return version
+
+
 class RpmDirConfig:
     ''' Placeholder for directory config '''
 
@@ -324,7 +339,8 @@ Provides: %{projectUp}_%{lbversion} = %{lhcb_maj_version}.%{lhcb_min_version}.%{
         tmp = ""
         # Dependencies to LHCb projects
         if self._manifest != None:
-            for (dproject, dversion) in self._manifest.getUsedProjects():
+            for (dproject, origversion) in self._manifest.getUsedProjects():
+                dvcersion = convertToLHCbClassicVersion(origversion)
                 if is_platform_independent(dproject, dversion):
                     tmp += "Requires: %s_%s\n" % (dproject.upper(), dversion)
                 else:
@@ -701,7 +717,8 @@ ${extraRequires}
         tmp = ""
 
         # Dependencies to LHCb projects
-        for (dproject, dversion) in self._manifest.getUsedProjects():
+        for (dproject, origversion) in self._manifest.getUsedProjects():
+            dversion = convertToLHCbClassicVersion(origversion)
             if is_platform_independent(dproject, dversion):
                 tmp += "Requires: %s_%s\n" % (dproject.upper(), dversion)
             else:
@@ -864,7 +881,8 @@ Requires: %{projectUp}_%{lbversion}
         tmp = ""
 
         # Dependencies to LHCb projects
-        for (dproject, dversion) in self._manifest.getUsedProjects():
+        for (dproject, origversion) in self._manifest.getUsedProjects():
+            dversion = convertToLHCbClassicVersion(origversion)
             tmp += "Requires: %s_%s_index\n" % (dproject.upper(), dversion)
         return tmp
 
